@@ -100,14 +100,14 @@ class Connector(object):
             LOG.debug('iDRAC is not yet ready after previous operation. '
                       'Error: %(err)s', {'err': exc_str})
             retry = True
-        elif 'iLO.2.15.InvalidOperationForSystemState' in exc_str:
+        elif 'iLO' in exc_str and 'InvalidOperationForSystemState' in exc_str:
             LOG.debug('iLO is not ready after previous operation. '
                       'Error: %(error)s', {'err': exc_str})
             retry = True
         return retry
 
     def _op(self, method, path='', data=None, headers=None, blocking=False,
-            timeout=60, server_side_retries_left=None,
+            timeout=60, server_side_retries_left=None, allow_reauth=True,
             **extra_session_req_kwargs):
         """Generic RESTful request handler.
 
@@ -117,9 +117,15 @@ class Connector(object):
         :param data: Optional JSON data.
         :param headers: Optional dictionary of headers.
         :param blocking: Whether to block for asynchronous operations.
-        :param timeout: Max time in seconds to wait for blocking async call.
+        :param timeout: Max time in seconds to wait for blocking async call or
+                        for requests library to connect and read. If a custom
+                        timeout for requests is provided in
+                        extra_session_req_kwargs, it will be used instead for
+                        those calls.
         :param server_side_retries_left: Remaining retries. If not provided
             will use limit provided by instance's server_side_retries
+        :param allow_reauth: Whether to allow refreshing the authentication
+            token.
         :param extra_session_req_kwargs: Optional keyword argument to pass
          requests library arguments which would pass on to requests session
          object.
@@ -127,7 +133,6 @@ class Connector(object):
         :raises: ConnectionError
         :raises: HTTPError
         """
-
         if server_side_retries_left is None:
             server_side_retries_left = self._server_side_retries
 
@@ -153,6 +158,7 @@ class Connector(object):
             response = self._session.request(method, url, json=data,
                                              headers=headers,
                                              verify=self._verify,
+                                             timeout=timeout,
                                              **extra_session_req_kwargs)
         except requests.exceptions.RequestException as e:
             # Capture any general exception by looking for the parent
@@ -180,6 +186,10 @@ class Connector(object):
                 LOG.error('Authentication to the session service failed. '
                           'Please check credentials and try again.')
                 raise
+            if not allow_reauth:
+                LOG.error("Failure occurred while attempting to retry "
+                          "request after refreshing the session: %s", e)
+                raise
             if self._auth is not None:
                 # self._session.auth value is only set when basic auth is used
                 if self._session.auth is not None:
@@ -201,22 +211,17 @@ class Connector(object):
                                     're-authenticate.')
                         self._auth.authenticate()
                 except exceptions.AccessError as refresh_exc:
-                    LOG.error("A failure occured while attempting to refresh "
+                    LOG.error("A failure occurred while attempting to refresh "
                               "the session. Error: %s", refresh_exc.message)
                     raise
                 LOG.debug("Authentication refreshed successfully, "
                           "retrying the call.")
-                try:
-                    response = self._session.request(
-                        method, url, json=data,
-                        headers=headers,
-                        verify=self._verify,
-                        **extra_session_req_kwargs)
-                except exceptions.HTTPError as retry_exc:
-                    LOG.error("Failure occured while attempting to retry "
-                              "request after refreshing the session. Error: "
-                              "%s", retry_exc.message)
-                    raise
+                return self._op(
+                    method, path, data=data, headers=headers,
+                    blocking=blocking, timeout=timeout,
+                    server_side_retries_left=server_side_retries_left,
+                    allow_reauth=False,
+                    **extra_session_req_kwargs)
             else:
                 if method == 'GET' and url.endswith('SessionService'):
                     LOG.debug('HTTP GET of SessionService failed %s, '
